# pyzitadelle

<a id="readme-top"></a> 

<div align="center">  
  <p align="center">
    PyZITADELLE is a quick asynchronous framework for testing python applications
    <br />
    <a href="https://alexeev-prog.github.io/pyzitadelle/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="#-comparison-with-alternatives">Comparison with Alternatives</a>
    .
    <a href="#-why-choose-pyechonext">Why Choose pyzitadelle</a>
    ·
    <a href="#-key-features">Key Features</a>
    ·
    <a href="#-getting-started">Getting Started</a>
    ·
    <a href="#-usage-examples">Basic Usage</a>
    ·
    <a href="#-specifications">Specification</a>
    ·
    <a href="https://alexeev-prog.github.io/pyzitadelle/">Documentation</a>
    ·
    <a href="https://github.com/alexeev-prog/pyzitadelle/blob/main/LICENSE">License</a>
  </p>
</div>
<br>
<p align="center">
    <img src="https://img.shields.io/github/languages/top/alexeev-prog/pyzitadelle?style=for-the-badge">
    <img src="https://img.shields.io/github/languages/count/alexeev-prog/pyzitadelle?style=for-the-badge">
    <img src="https://img.shields.io/github/license/alexeev-prog/pyzitadelle?style=for-the-badge">
    <img src="https://img.shields.io/github/stars/alexeev-prog/pyzitadelle?style=for-the-badge">
    <img src="https://img.shields.io/github/issues/alexeev-prog/pyzitadelle?style=for-the-badge">
    <img src="https://img.shields.io/github/last-commit/alexeev-prog/pyzitadelle?style=for-the-badge">
</p>
